==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebGridMasterDetailContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridMasterDetailContextDescription } from "./WebGridMasterDetailContextDescription";
/**
 * @hidden
 */
var WebGridMasterDetailContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridMasterDetailContextDescriptionMetadata, _super);
    function WebGridMasterDetailContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridMasterDetailContextDescriptionMetadata.b = function (a) {
        if (WebGridMasterDetailContextDescriptionMetadata.a == null) {
            WebGridMasterDetailContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridMasterDetailContextDescriptionMetadata.c(WebGridMasterDetailContextDescriptionMetadata.a);
        }
        if (a.j(WebGridMasterDetailContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridMasterDetailContextDescriptionMetadata.a);
    };
    WebGridMasterDetailContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridMasterDetailContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "Unknown");
        a.item("Index", "Number:double");
    };
    WebGridMasterDetailContextDescriptionMetadata.d = function (a) {
        WebGridMasterDetailContextDescriptionMetadata.b(a);
        a.aa("WebGridMasterDetailContext", function () { return new WebGridMasterDetailContextDescription(); });
        a.z("WebGridMasterDetailContext", WebGridMasterDetailContextDescriptionMetadata.a);
    };
    WebGridMasterDetailContextDescriptionMetadata.$t = markType(WebGridMasterDetailContextDescriptionMetadata, 'WebGridMasterDetailContextDescriptionMetadata');
    WebGridMasterDetailContextDescriptionMetadata.a = null;
    return WebGridMasterDetailContextDescriptionMetadata;
}(Base));
export { WebGridMasterDetailContextDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridMasterDetailContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridMasterDetailContextDescription } from "./WebGridMasterDetailContextDescription";
/**
 * @hidden
 */
var WebGridMasterDetailContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridMasterDetailContextDescriptionMetadata, _super);
    function WebGridMasterDetailContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridMasterDetailContextDescriptionMetadata.b = function (a) {
        if (WebGridMasterDetailContextDescriptionMetadata.a == null) {
            WebGridMasterDetailContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridMasterDetailContextDescriptionMetadata.c(WebGridMasterDetailContextDescriptionMetadata.a);
        }
        if (a.k(WebGridMasterDetailContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridMasterDetailContextDescriptionMetadata.a);
    };
    WebGridMasterDetailContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridMasterDetailContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "Unknown");
        a.item("Index", "Number:double");
    };
    WebGridMasterDetailContextDescriptionMetadata.d = function (a) {
        WebGridMasterDetailContextDescriptionMetadata.b(a);
        a.ac("WebGridMasterDetailContext", function () { return new WebGridMasterDetailContextDescription(); });
        a.ab("WebGridMasterDetailContext", WebGridMasterDetailContextDescriptionMetadata.a);
    };
    WebGridMasterDetailContextDescriptionMetadata.$t = markType(WebGridMasterDetailContextDescriptionMetadata, 'WebGridMasterDetailContextDescriptionMetadata');
    WebGridMasterDetailContextDescriptionMetadata.a = null;
    return WebGridMasterDetailContextDescriptionMetadata;
}(Base));
export { WebGridMasterDetailContextDescriptionMetadata };
